@@ -29,8 +29,14 @@ from mitosheet.step_performers import (
     DataframeRenameStepPerformer,
     BulkOldRenameStepPerformer, 
     ExcelImportStepPerformer,
-    DropDuplicatesStepPerformer
+    DropDuplicatesStepPerformer,
+    GraphStepPerformer,
+    ConcatStepPerformer
 )
+from mitosheet.step_performers.fill_na import FillNaStepPerformer
+from mitosheet.step_performers.graph_steps.graph_delete import GraphDeleteStepPerformer
+from mitosheet.step_performers.graph_steps.graph_duplicate import GraphDuplicateStepPerformer
+from mitosheet.step_performers.graph_steps.graph_rename import GraphRenameStepPerformer
 
 def check_step(
         step_performer: StepPerformer, 
@@ -181,7 +187,43 @@ def test_params_static():
         'drop_duplicates'
     )
 
-    assert len(STEP_PERFORMERS) == 19
+    check_step(
+        GraphStepPerformer,
+        3,
+        'graph'
+    )
+
+    check_step(
+        GraphDeleteStepPerformer,
+        1,
+        'graph_delete'
+    )
+
+    check_step(
+        GraphDuplicateStepPerformer,
+        1,
+        'graph_duplicate'
+    )
+
+    check_step(
+        GraphRenameStepPerformer,
+        1,
+        'graph_rename'
+    )
+
+    check_step(
+        ConcatStepPerformer,
+        1,
+        'concat'
+    )
+
+    check_step(
+        FillNaStepPerformer,
+        1,
+        'fill_na'
+    )
+
+    assert len(STEP_PERFORMERS) == 25
 
 
 def get_fake_param(param_name):
