@@ -9,7 +9,8 @@ This file contains helpful functions and classes for testing operations.
 
 import json
 from functools import wraps
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Union
+from mitosheet.code_chunks.code_chunk_utils import get_code_chunks
 from mitosheet.step_performers.graph_steps.plotly_express_graphs import DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT, DO_NOT_CHANGE_PLOT_BGCOLOR_DEFAULT, DO_NOT_CHANGE_TITLE_FONT_COLOR_DEFAULT
 from numpy import number
 
@@ -125,7 +126,13 @@ class MitoWidgetTestWrapper:
     def transpiled_code(self):
         # NOTE: we don't add comments to this testing functionality, so that 
         # we don't have to change tests if we update comments
-        return transpile(self.mito_widget.steps_manager, add_comments=False)['code']
+        return transpile(self.mito_widget.steps_manager, add_comments=False)
+    
+    @property
+    def optimized_code_chunks(self):
+        # NOTE: we don't add comments to this testing functionality, so that 
+        # we don't have to change tests if we update comments
+        return get_code_chunks(self.mito_widget.steps_manager.steps, optimize=True)
 
     @property
     def curr_step_idx(self):
@@ -274,6 +281,34 @@ class MitoWidgetTestWrapper:
                 }
             }
         )
+    
+    @check_transpiled_code_after_call
+    def fill_na(
+            self, 
+            sheet_index: int,
+            column_headers: List[ColumnHeader],
+            fill_method: Any
+        ) -> bool:
+
+        column_ids = [
+            self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(sheet_index, column_header)
+            for column_header in column_headers
+        ]
+
+        return self.mito_widget.receive_message(
+            self.mito_widget,
+            {
+                'event': 'edit_event',
+                'id': get_new_id(),
+                'type': 'fill_na_edit',
+                'step_id': get_new_id(),
+                'params': {
+                    'sheet_index': sheet_index,
+                    'column_ids': column_ids,
+                    'fill_method': fill_method
+                }
+            }
+        )
 
     @check_transpiled_code_after_call
     def drop_duplicates(
@@ -416,7 +451,8 @@ class MitoWidgetTestWrapper:
             self, 
             sheet_index: int, 
             column_header: ColumnHeader,
-            sort_direction: str
+            sort_direction: str,
+            step_id: str=None
         ) -> bool:
 
         column_id = self.mito_widget.steps_manager.curr_step.column_ids.get_column_id_by_header(
@@ -430,7 +466,7 @@ class MitoWidgetTestWrapper:
                 'event': 'edit_event',
                 'id': get_new_id(),
                 'type': 'sort_edit',
-                'step_id': get_new_id(),
+                'step_id': get_new_id() if step_id is None else step_id,
                 'params': {
                     'sheet_index': sheet_index,
                     'column_id': column_id,
@@ -616,7 +652,8 @@ class MitoWidgetTestWrapper:
             {
                 'event': 'update_event',
                 'id': get_new_id(),
-                'type': 'undo'
+                'type': 'undo',
+                'params': {},
             }
         )
 
@@ -627,7 +664,8 @@ class MitoWidgetTestWrapper:
             {
                 'event': 'update_event',
                 'id': get_new_id(),
-                'type': 'redo'
+                'type': 'redo',
+                'params': {},
             }
         )
 
@@ -638,7 +676,8 @@ class MitoWidgetTestWrapper:
             {
                 'event': 'update_event',
                 'id': get_new_id(),
-                'type': 'clear'
+                'type': 'clear',
+                'params': {},
             }
         )
     
@@ -650,7 +689,9 @@ class MitoWidgetTestWrapper:
                 'event': 'update_event',
                 'id': get_new_id(),
                 'type': 'save_analysis_update',
-                'analysis_name': analysis_name
+                'params': {
+                    'analysis_name': analysis_name
+                },
             }
         )
 
@@ -725,16 +766,16 @@ class MitoWidgetTestWrapper:
         )
 
     @check_transpiled_code_after_call
-    def replay_analysis(self, analysis_name: str, import_summaries: Dict[str, Any]=None, clear_existing_analysis: bool=False) -> bool:
+    def replay_analysis(self, analysis_name: str) -> bool:
         return self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'update_event',
                 'id': get_new_id(),
                 'type': 'replay_analysis_update',
-                'analysis_name': analysis_name,
-                'import_summaries': import_summaries,
-                'clear_existing_analysis': clear_existing_analysis
+                'params': {
+                    'analysis_name': analysis_name,
+                },
             }
         )
 
@@ -746,7 +787,9 @@ class MitoWidgetTestWrapper:
                 'event': 'update_event',
                 'id': get_new_id(),
                 'type': 'checkout_step_by_idx_update',
-                'step_idx': index,
+                'params': {
+                    'step_idx': index,
+                },
             }
         )
 
